<?php
// $Id: multistep.admin.inc,v 1.1.2.4 2009/07/23 14:48:59 vkareh Exp $

/**
 * Displays the administrative settings page
 */
function multistep_admin_settings() {
  return drupal_get_form('multistep_admin_settings_form');
}

/**
 * Creates the form used for admin settings.
 */
function multistep_admin_settings_form(&$form_state) {
  $form = array();
  // Navigation buttons
  $form['multistep']['buttons'] = array(
    '#type' => 'fieldset',
    '#title' => 'Navigation button labels',
    '#description' => t('These settings will change the text displayed on each of the submit buttons on multistep forms.'),
    '#weight' => 0,
  );
  $form['multistep']['buttons']['multistep_button_prev'] = array(
    '#type' => 'textfield',
    '#title' => t('Previous button'),
    '#default_value' => variable_get('multistep_button_prev', '< Previous'),
    '#description' => t('This button will bring you back one step.'),
    '#weight' => -10,
  );
  $form['multistep']['buttons']['multistep_button_next'] = array(
    '#type' => 'textfield',
    '#title' => t('Next button'),
    '#default_value' => variable_get('multistep_button_next', 'Next >'),
    '#description' => t('This button will move you forward one step.'),
    '#weight' => -9,
  );
  $form['multistep']['buttons']['multistep_button_save'] = array(
    '#type' => 'textfield',
    '#title' => t('Save button'),
    '#default_value' => variable_get('multistep_button_save', 'Save'),
    '#description' => t('This button will save the form while remaining in the current step.'),
    '#weight' => -8,
  );
  $form['multistep']['buttons']['multistep_button_done'] = array(
    '#type' => 'textfield',
    '#title' => t('Done button'),
    '#default_value' => variable_get('multistep_button_done', 'Done'),
    '#description' => t('This button will save the form and redirect you to the node view.'),
    '#weight' => -7,
  );
  $form['multistep']['buttons']['multistep_submit_buttons'] = array(
    '#type' => 'submit',
    '#value' => t('Save button labels'),
    '#weight' => 1,
    '#access' => user_access('administer multistep'),
    '#validate' => array('multistep_admin_settings_buttons_form_validate'),
    '#submit' => array('multistep_admin_settings_buttons_form_submit'),
  );
  // Reset data
  $form['multistep']['reset'] = array(
    '#type' => 'fieldset',
    '#title' => 'Reset data',
    '#description' => t('This form will reset all the step data for the selected content type. Use this if you just enabled multistep for a content type that already contained nodes.') . '<br /><strong>' . t('Warning! Resetting the tables for a content type that already had multistep enabled could result in the loss of the step data!') . '</strong>',
    '#weight' => 1,
  );
  $content_types = content_types();
  $options = array('' => '- Select -');
  foreach ($content_types as $content_type) {
    if (variable_get('multistep_expose_' . $content_type['type'], 'disabled') == 'enabled') {
      $options[$content_type['type']] = $content_type['name'];
    }
  }
  $form['multistep']['reset']['multistep_type'] = array(
    '#type' => 'select',
    '#title' => t('Content type'),
    '#options' => $options,
    '#weight' => -1,
  );
  // Show reset button if multistep is enabled for this content type.
  $form['multistep']['reset']['multistep_reset'] = array(
    '#type' => 'submit',
    '#value' => t('Reset data'),
    '#weight' => 1,
    '#access' => user_access('administer multistep'),
    '#validate' => array('multistep_admin_settings_reset_form_validate'),
    '#submit' => array('multistep_admin_settings_reset_form_submit'),
  );
  return $form;
}

/**
 * Validates the navigation button labels form to make sure they contain text.
 */
function multistep_admin_settings_buttons_form_validate($form, &$form_state) {
  if (empty($form_state['values']['multistep_button_prev']) || !isset($form_state['values']['multistep_button_prev'])) {
    form_set_error('multistep_button_prev', 'You need to enter a label for the <em>Previous</em> button.');
  }
  if (empty($form_state['values']['multistep_button_next']) || !isset($form_state['values']['multistep_button_next'])) {
    form_set_error('multistep_button_next', 'You need to enter a label for the <em>Next</em> button.');
  }
  if (empty($form_state['values']['multistep_button_save']) || !isset($form_state['values']['multistep_button_save'])) {
    form_set_error('multistep_button_save', 'You need to enter a label for the <em>Save</em> button.');
  }
  if (empty($form_state['values']['multistep_button_done']) || !isset($form_state['values']['multistep_button_done'])) {
    form_set_error('multistep_button_done', 'You need to enter a label for the <em>Done</em> button.');
  }
}

/**
 * Saves the navigation button labels.
 */
function multistep_admin_settings_buttons_form_submit($form, &$form_state) {
  variable_set('multistep_button_prev', $form_state['values']['multistep_button_prev']);
  variable_set('multistep_button_next', $form_state['values']['multistep_button_next']);
  variable_set('multistep_button_save', $form_state['values']['multistep_button_save']);
  variable_set('multistep_button_done', $form_state['values']['multistep_button_done']);
  drupal_set_message(t('Button labels saved successfully.'));
}

/**
 * Validates the reset data form to make sure a content type was selected.
 */
function multistep_admin_settings_reset_form_validate($form, &$form_state) {
  if (empty($form_state['values']['multistep_type']) || !isset($form_state['values']['multistep_type'])) {
    form_set_error('multistep_type', 'You need to select which content type you want to reset the data for.');
  }
}

/**
 * Resets the multistep table data for the selected content type.
 */
function multistep_admin_settings_reset_form_submit($form, &$form_state) {
  _multistep_reset_data($form_state['values']['multistep_type']);
  drupal_set_message(t('Data was reset successfully.'));
}
